#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_NEXTAFTER_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_NEXTAFTER_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/nextafter.hpp>

#endif
